@@ -209,12 +209,24 @@ void Context::transform(const Matrix& matrix)
   check_object_status_and_throw_exception(*this);
 }
 
+void Context::transform(const cairo_matrix_t& matrix)
+{
+  cairo_transform(cobj(), &matrix);
+  check_object_status_and_throw_exception(*this);
+}
+
 void Context::set_matrix(const Matrix& matrix)
 {
   cairo_set_matrix(cobj(), &matrix);
   check_object_status_and_throw_exception(*this);
 }
 
+void Context::set_matrix(const cairo_matrix_t& matrix)
+{
+  cairo_set_matrix(cobj(), &matrix);
+  check_object_status_and_throw_exception(*this);
+}
+
 void Context::set_identity_matrix()
 {
   cairo_identity_matrix(cobj());
@@ -467,12 +479,24 @@ void Context::set_font_matrix(const Matrix& matrix)
   check_object_status_and_throw_exception(*this);
 }
 
+void Context::set_font_matrix(const cairo_matrix_t& matrix)
+{
+  cairo_set_font_matrix(cobj(), &matrix);
+  check_object_status_and_throw_exception(*this);
+}
+
 void Context::get_font_matrix(Matrix& matrix) const
 {
   cairo_get_font_matrix(const_cast<cobject*>(cobj()), &matrix);
   check_object_status_and_throw_exception(*this);
 }
 
+void Context::get_font_matrix(cairo_matrix_t& matrix) const
+{
+  cairo_get_font_matrix(const_cast<cobject*>(cobj()), &matrix);
+  check_object_status_and_throw_exception(*this);
+}
+
 void Context::set_font_options(const FontOptions& options)
 {
   cairo_set_font_options(cobj(), options.cobj());
@@ -698,6 +722,12 @@ void Context::get_matrix(Matrix& matrix)
   check_object_status_and_throw_exception(*this);
 }
 
+void Context::get_matrix(cairo_matrix_t& matrix)
+{
+  cairo_get_matrix(cobj(), &matrix);
+  check_object_status_and_throw_exception(*this);
+}
+
 Matrix Context::get_matrix() const
 {
   Cairo::Matrix m;
